/* src/math1/vrblib/vrfnb.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     VRFNB */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int vrfnb_(real *rx, real *ry, real *rz, integer *n, integer 
	*jx, integer *jy, integer *jz, U_fp rfnb)
{
    static logical lmiss;
    extern /* Subroutine */ int vrfnb0_(real *, real *, real *, integer *, 
	    integer *, integer *, integer *, U_fp), vrfnb1_(real *, real *, 
	    real *, integer *, integer *, integer *, integer *, U_fp), 
	    gllget_(char *, logical *, ftnlen);

    /* Parameter adjustments */
    --rz;
    --ry;
    --rx;

    /* Function Body */
    gllget_("LMISS", &lmiss, (ftnlen)5);
    if (lmiss) {
	vrfnb1_(&rx[1], &ry[1], &rz[1], n, jx, jy, jz, (U_fp)rfnb);
    } else {
	vrfnb0_(&rx[1], &ry[1], &rz[1], n, jx, jy, jz, (U_fp)rfnb);
    }
    return 0;
} /* vrfnb_ */

